@@ -14,7 +14,7 @@ OctocatalogDiff::Cli::Options::Option.newoption(:puppet_master_timeout) do
       cli_name: 'puppet-master-timeout',
       option_name: 'puppet_master_timeout',
       desc: 'Puppet Master catalog retrieval timeout in seconds',
-      validator: ->(x) { x.to_i > 0 || raise(ArgumentError, 'Specify timeout as a integer greater than 0') },
+      validator: ->(x) { x.to_i > 0 || raise(ArgumentError, 'Specify timeout as an integer greater than 0') },
       translator: ->(x) { x.to_i }
     )
   end
